package com.gic.store.service.outer.impl;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.store.dto.ClerkPositionDTO;
import com.gic.store.entity.TabClerkPosition;
import com.gic.store.service.ClerkPositionApiService;
import com.gic.store.service.ClerkPositionService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service("clerkPositionApiService")
public class ClerkPositionApiServiceImpl implements ClerkPositionApiService {

    @Autowired
    private ClerkPositionService clerkPositionService;

    @Override
    public ServiceResponse<Void> save(ClerkPositionDTO clerkPositionDTO) {
        // 校验参数
        if (clerkPositionService.isPositionNameRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionName(), null)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色名称错误");
        }
        if (clerkPositionService.isPositionCodeRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionCode(), null)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色代码错误");
        }
        // 保存实体
        clerkPositionService.save(clerkPositionDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> update(ClerkPositionDTO clerkPositionDTO) {
        if (clerkPositionService.isPositionNameRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionName(), clerkPositionDTO.getClerkPositionId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色名称错误");
        }
        if (clerkPositionService.isPositionCodeRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionCode(), clerkPositionDTO.getClerkPositionId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色代码错误");
        }
        // 保存实体
        clerkPositionService.update(clerkPositionDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<ClerkPositionDTO> getByClerkPositionId(Integer clerkPositionId) {
        TabClerkPosition clerkPosition = this.clerkPositionService.getByClerkPositionId(clerkPositionId);
        ClerkPositionDTO clerkPositionDTO = EntityUtil.changeEntityByJSON(ClerkPositionDTO.class, clerkPosition);
        return EnterpriseServiceResponse.success(clerkPositionDTO);
    }

    @Override
    public ServiceResponse<Page<ClerkPositionDTO>> listClerkPosition(Integer enterpriseId, String search, Integer currentPage, Integer pageSize) {
        com.github.pagehelper.Page<TabClerkPosition> clerkPositionList = clerkPositionService.listClerkPosition(enterpriseId, search, currentPage, pageSize);
        Page<ClerkPositionDTO> clerkPositionDTOPage = PageHelperUtils.changePageHelperToCurrentPage(clerkPositionList, ClerkPositionDTO.class);
        if (CollectionUtils.isNotEmpty(clerkPositionList)) {
            List<ClerkPositionDTO> positionDTOList = clerkPositionDTOPage.getResult();
            for (int i = 0; i < positionDTOList.size(); i++) {
                positionDTOList.get(i).setSeq(i + 1);
            }
        }
        return EnterpriseServiceResponse.success(clerkPositionDTOPage);
    }

    @Override
    public ServiceResponse<List<ClerkPositionDTO>> listAllClerkPosition(Integer enterpriseId, String search) {
        List<TabClerkPosition> clerkPositionList = clerkPositionService.listAllClerkPosition(enterpriseId, search);
        return EnterpriseServiceResponse.success(EntityUtil.changeEntityListByJSON(ClerkPositionDTO.class, clerkPositionList));
    }

    @Override
    public ServiceResponse<Void> setSort(Integer enterpriseId, Integer clerkPositionId, Integer seq) {
        clerkPositionService.setSort(enterpriseId, clerkPositionId, seq);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<ClerkPositionDTO> getByName(Integer enterpriseId, String positionName) {
        TabClerkPosition position = clerkPositionService.getByName(enterpriseId, positionName);
        return EnterpriseServiceResponse.success(EntityUtil.changeEntityByJSON(ClerkPositionDTO.class, position));
    }

    @Override
    public ServiceResponse<Void> delete(Integer clerkPositionId) {
        TabClerkPosition clerkPosition = this.clerkPositionService.getByClerkPositionId(clerkPositionId);
        if (clerkPosition == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "数据不存在或已删除");
        }
        this.clerkPositionService.deleteById(clerkPositionId);
        return EnterpriseServiceResponse.success();
    }

}